#################################################################################################
###############       INSTITUTO NACIONAL DE ESTADISTICA Y CENSOS - INEC           ###############
###############              DIRECCION DE ESTADISTICAS ECONOMICAS                 ###############
###############          DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS - DIEE         ###############
###############                                                                   ###############
############### TABULADOS DEL DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS, AO 2019 ###############           
#################################################################################################
#Elaborada 25-10-2019.
#Actualizado 24-08-2020
#Actualizada 15-10-2020

#Requerimientos##################################################################################
#Es necesario crear un proyecto dentro del mismo deberan estar los siguientes archivos:
#FORMATO SPSS: BASES DE DATOS PUBLICADAS: "DIEE_EMPRESAS_2019_periodo2006_2011"
#                                         "DIEE_EMPRESAS_2019_periodo2012_2019"
#FORMATO EXCEL: CATLOGO : "diee_catalogo"
#               PLANTILLA EN BLANCO: "Tabulados_DIEE_2019"
#FORMATO R : SCRIPT_TABULADOS_DIEE_2019
#################################################################################################

#librerias y paquetes#
library(dplyr)
library(openxlsx)
library(reshape2)
library(foreign)
library(data.table)
library(writexl)
install.packages("zipR")

####################################### BASE DE DATOS ##########################################
#Aumentar la capacidad de almacenamiento
memory.limit(size=56000)
#Lectura de la base de datos.
######BASE DE DATOS 2012_2019###################
bd_diee <- read.spss("DIEE_EMPRESAS_2019_periodo2012_2019.sav",use.value.labels=F,to.data.frame = T)
######BASE DE DATOS 2006_2011
bd_diee2 <- read.spss("DIEE_EMPRESAS_2019_periodo2006_2011.sav",use.value.labels=F,to.data.frame = T)
bd_diee1 <- bd_diee2 %>% filter(situacion==1)

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )

###########Formato / color####################
newStyle <- createStyle(fgFill = "#FFFFFF") #blanco
grisStyle <- createStyle(fgFill = "#D9D9D9") #gris

####################################### FUNCIONES ##############################################

#########SECCIÓN I: número de empresas##################

################TABULADO 1###############################
###EMPRESAS SEGÚN PARTICIPACIÓN NACIONAL,             ###
###AÑO 2019 POR ESTRUCTURA PARA ESTRATIFICACION       ###

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_estrato <- bd_dieeact %>% group_by(estructura_estrat) %>% summarise("total_estrato"=n(),porcentaje = 0)
total <- as.numeric(sum(t_estrato$total_estrato,na.rm =T ))
t_estrato$porcentaje <- t_estrato$total_estrato / total

#Lectura catalogo de variables.
des_estrato <- read.xlsx("diee_catologo.xlsx", sheet = "estructura_estratificacion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_estrato,t_estrato,by.x = "CODIGO",by.y = "estructura_estrat",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_estrato,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb1,sheet = "1","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb1,sheet = "1",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb1,sheet = "1",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb1,sheet = "1",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb1,"1",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb1,"1",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado1 <- saveWorkbook(wb1,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 2 ##################################
###TOTAL EMPRESAS (UNIVERSO DIEE), PERIODO 2012 - 2019 POR ANO###	

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee %>% filter(situacion==1 )
#Total empresas del anio 2012-2019
total_anios <- bd_dieeact %>% group_by(anio) %>% summarise("total_anios"=n())

#Exportar resultados a excel
wb2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb2,sheet = "2",total_anios, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb2,"2",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb2,"2",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado2 <- saveWorkbook(wb2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#####################TABULADO 3###################################
#EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019#
#               POR FORMA INSTITUCIONAL 	                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieefi <- df1 %>% filter(anio == 2019 & situacion==1 )

#calculo de las variables
t_formainstitucional <- bd_dieefi %>% group_by(forma_institucional) %>% summarise("total_formainstitucional"=n(),porcentaje = 0)
total <- sum(t_formainstitucional$total_formainstitucional,na.rm =T )
t_formainstitucional$porcentaje <- t_formainstitucional$total_formainstitucional / total

#Lectura catalogo de variables.
des_formainstitucional <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_formainstitucional,t_formainstitucional,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_formainstitucional,porcentaje)
t_estrato2 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb3<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb3,sheet = "3","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb3,sheet = "3",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb3,sheet = "3",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb3,sheet = "3",t_estrato2,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb3,"3",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3,"3",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3 <- saveWorkbook(wb3,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 4#################################
#EMPRESAS SEGUNN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019##
#                    POR TAMANO DE EMPRESA                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanop_plazas,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_tamano <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise("total_tamano"=n(),porcentaje = 0)
total <- sum(t_tamano$total_tamano,na.rm =T )
t_tamano$porcentaje <- t_tamano$total_tamano / total

#Lectura catalogo de variables.
des_tamano <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamano,t_tamano,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_tamano,porcentaje)
t_estrato3 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb4<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb4,sheet = "4","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb4,sheet = "4",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb4,sheet = "4",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb4,sheet = "4",t_estrato3,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb4,"4",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"4",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"4",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado4 <- saveWorkbook(wb4,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 5#################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019 #
#                    POR SECTOR ECONOMICO                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_sectores <- bd_dieeact %>% group_by(gsectores) %>% summarise("total_sectores"=n(),porcentaje = 0)
total <- sum(t_sectores$total_sectores,na.rm =T )
t_sectores$porcentaje <- t_sectores$total_sectores / total

#Lectura catalogo de variables.
des_sectores <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectores,t_sectores,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_sectores,porcentaje)
t_estrato4 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb5<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb5,sheet = "5","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb5,sheet = "5",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb5,sheet = "5",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb5,sheet = "5",t_estrato4,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb5,"5",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb5,"5",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado5 <- saveWorkbook(wb5,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 6#################################
#  EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019#
#                POR ACTIVIDAD ECONOMICA                           #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_seccion <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise("total_seccion"=n(),porcentaje = 0)
total <- sum(t_seccion$total_seccion,na.rm =T )
t_seccion$porcentaje <- t_seccion$total_seccion / total

#Lectura catalogo de variables.
des_seccion <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccion,t_seccion,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_seccion,porcentaje)
t_estrato5 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb6<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb6,sheet = "6","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb6,sheet = "6",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb6,sheet = "6",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb6,sheet = "6",t_estrato5,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb6,"6",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb6,"6",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado6 <- saveWorkbook(wb6,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 7################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019#
#                     POR PROVINCIA                               #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_provincia <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise("total_provincia"=n(),porcentaje = 0)
total <- sum(t_provincia$total_provincia,na.rm =T )
t_provincia$porcentaje <- t_provincia$total_provincia / total

##lectura de excel para llenar###
des_provincia <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provincia,t_provincia,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_provincia,porcentaje)
t_estrato6 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb7<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb7,sheet = "7","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb7,sheet = "7",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb7,sheet = "7",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb7,sheet = "7",t_estrato6,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb7,"7",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7,"7",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7 <- saveWorkbook(wb7,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########SECCIÓN II: ventas##################

###################TABULADO 8###############################
#      VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2019 #
#                   POR ANIO                               #

# Lectura de base 2009-2011

bd_dieeventas <- bd_diee1 %>% select(ventas_totales,anio,situacion,exportaciones_netas,ventas_nacionales)
d_dieeven <- bd_dieeventas %>% filter (anio != 2006 & anio != 2007 & anio != 2008)

#VENTAS TOTALES#
#Total empresas del año 2009-2011#
t_ventas1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb8<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb8,sheet = "8",t_ventas1, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado8 <- saveWorkbook(wb8,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#VENTAS NACIONALES#
#total empresas del ao 2009 - 2011#
t_vntanacional1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
t_vntanacional2 <- t_vntanacional1 %>% select(total_ventanacional)

#Exportar resultados a excel
wb82<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb82,sheet = "8",t_vntanacional2, startCol = 3,startRow = 7,colNames = F) ##escribir
tabulado82 <- saveWorkbook(wb82,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#EXPORTACIONES#
#total empresas del ao 2009 - 2011#
t_exportaciones1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
t_exportaciones2 <- t_exportaciones1 %>% select(total_exportaciones)

#Exportar resultados a excel
wb83<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb83,sheet = "8",t_exportaciones2, startCol = 4,startRow = 7,colNames = F) ##escribir
tabulado83 <- saveWorkbook(wb83,"Tabulados_DIEE_2019.xlsx",overwrite = T)
                          
#Lectura de la base de datos 2012-2019
bd_diee2 <- bd_diee %>% select(ventas_totales,anio,situacion,exportaciones_netas,ventas_nacionales)
bd_dieeac2 <- bd_diee2 %>% filter (situacion == 1)

#Total empresas del año 2012-2019
t_ventas2 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb81<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb81,sheet = "8",t_ventas2, startCol = 1,startRow = 10,colNames = F) ##escribir
addStyle(wb81,"8",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb81,"8",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado81 <- saveWorkbook(wb81,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#VENTAS NACIONALES#
#total empresas del ao 2012 - 2019#
t_vntanacional11 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
t_vntanacional22 <- t_vntanacional11 %>% select(total_ventanacional)

#Exportar resultados a excel
wb822<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb822,sheet = "8",t_vntanacional22, startCol = 3,startRow = 10,colNames = F) ##escribir
tabulado822 <- saveWorkbook(wb822,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#EXPORTACIONES#
#total empresas del ao 2012 - 2019#
t_exportaciones11 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
t_exportaciones22 <- t_exportaciones11 %>% select(total_exportaciones)

#Exportar resultados a excel
wb833<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb833,sheet = "8",t_exportaciones22, startCol = 4,startRow = 10,colNames = F) ##escribir
addStyle(wb833,"8",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb833,"8",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado833 <- saveWorkbook(wb833,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###############TABULADO 9 (CONSTANTES)#########################
###VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2019 POR ANIO

#lectura de base 2009
bd_dieeventas3 <- bd_diee1 %>% select(ventas_totales,anio,situacion,ventas_nacionales, exportaciones_netas)
d_dieeven3 <- bd_dieeventas3 %>% filter (anio == 2009 )
t_ventas2009 <- d_dieeven3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/114.593630834947)*100,na.rm=T))

#Exportar resultados a excel
wb9<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb9,sheet = "9",t_ventas2009, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado9 <- saveWorkbook(wb9,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2009 <- d_dieeven3 %>% summarise ("total_ventas"=sum((ventas_nacionales/114.593630834947)*100,na.rm=T))
    t_ventanacional09<- t_ventanacional2009 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_1,sheet = "9",t_ventanacional09, startCol = 3,startRow = 7,colNames = F) ##escribir
    tabulado9_1 <- saveWorkbook(wb9_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2009 <- d_dieeven3 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/114.593630834947)*100,na.rm=T))
    t_exportaciones09<- t_exportaciones2009 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_2,sheet = "9",t_exportaciones09, startCol = 4,startRow = 7,colNames = F) ##escribir
    tabulado9_2 <- saveWorkbook(wb9_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)


#lectura de base 2010
bd_dieeventas4 <- bd_diee1 %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven4 <- bd_dieeventas4 %>% filter (anio == 2010 & situacion == 1)
t_ventas2010 <- d_dieeven4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/123.148137016917)*100,na.rm=T))

#Exportar resultados a excel
wb91<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb91,sheet = "9",t_ventas2010, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado91 <- saveWorkbook(wb91,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2010 <- d_dieeven4 %>% summarise ("total_ventas"=sum((ventas_nacionales/123.148137016917)*100,na.rm=T))
    t_ventanacional10<- t_ventanacional2010 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_11<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_11,sheet = "9",t_ventanacional10, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado9_11 <- saveWorkbook(wb9_11,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2010 <- d_dieeven4 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/123.148137016917)*100,na.rm=T))
    t_exportaciones10<- t_exportaciones2010 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_12<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_12,sheet = "9",t_exportaciones10, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado9_12 <- saveWorkbook(wb9_12,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2011
bd_dieeventas5 <- bd_diee1 %>% select(ventas_totales,anio,situacion, ventas_nacionales,exportaciones_netas)
d_dieeven5 <- bd_dieeventas5 %>% filter (anio == 2011 & situacion == 1)
t_ventas2011 <- d_dieeven5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb92<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb92,sheet = "9",t_ventas2011, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado92 <- saveWorkbook(wb92,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2011 <- d_dieeven5 %>% summarise ("total_ventas"=sum((ventas_nacionales/130.12159330682)*100,na.rm=T))
    t_ventanacional11<- t_ventanacional2011 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_21<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_21,sheet = "9",t_ventanacional11, startCol = 3,startRow = 9,colNames = F) ##escribir
    tabulado9_21 <- saveWorkbook(wb9_21,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2011 <- d_dieeven5 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/130.12159330682)*100,na.rm=T))
    t_exportaciones11<- t_exportaciones2011 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_22<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_22,sheet = "9",t_exportaciones11, startCol = 4,startRow = 9,colNames = F) ##escribir
    tabulado9_22 <- saveWorkbook(wb9_22,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeventas6 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven6 <- bd_dieeventas6 %>% filter (anio == 2012 & situacion == 1)
t_ventas2012 <- d_dieeven6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb93<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb93,sheet = "9",t_ventas2012, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado93 <- saveWorkbook(wb93,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2012 <- d_dieeven6 %>% summarise ("total_ventas"=sum((ventas_nacionales/136.608484020484)*100,na.rm=T))
    t_ventanacional12<- t_ventanacional2012 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_31<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_31,sheet = "9",t_ventanacional12, startCol = 3,startRow = 10,colNames = F) ##escribir
    tabulado9_31 <- saveWorkbook(wb9_31,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2012 <- d_dieeven6 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/136.608484020484)*100,na.rm=T))
    t_exportaciones12<- t_exportaciones2012 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_32<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_32,sheet = "9",t_exportaciones12, startCol = 4,startRow = 10,colNames = F) ##escribir
    tabulado9_32 <- saveWorkbook(wb9_32,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeventas7 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven7 <- bd_dieeventas7 %>% filter (anio == 2013 & situacion == 1)
t_ventas2013 <- d_dieeven7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb94<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb94,sheet = "9",t_ventas2013, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado94 <- saveWorkbook(wb94,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2013 <- d_dieeven7 %>% summarise ("total_ventas"=sum((ventas_nacionales/140.836583556647)*100,na.rm=T))
    t_ventanacional13<- t_ventanacional2013 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_41<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_41,sheet = "9",t_ventanacional13, startCol = 3,startRow = 11,colNames = F) ##escribir
    tabulado9_41 <- saveWorkbook(wb9_41,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2013 <- d_dieeven7 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/140.836583556647)*100,na.rm=T))
    t_exportaciones13<- t_exportaciones2013 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_42<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_42,sheet = "9",t_exportaciones13, startCol = 4,startRow = 11,colNames = F) ##escribir
    tabulado9_42 <- saveWorkbook(wb9_42,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeventas8 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven8 <- bd_dieeventas8 %>% filter (anio == 2014 & situacion == 1)
t_ventas2014 <- d_dieeven8 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb95<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb95,sheet = "9",t_ventas2014, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado95 <- saveWorkbook(wb95,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2014 <- d_dieeven8 %>% summarise ("total_ventas"=sum((ventas_nacionales/145.104922216934)*100,na.rm=T))
    t_ventanacional14<- t_ventanacional2014 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_51<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_51,sheet = "9",t_ventanacional14, startCol = 3,startRow = 12,colNames = F) ##escribir
    tabulado9_51 <- saveWorkbook(wb9_51,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2014 <- d_dieeven8 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/145.104922216934)*100,na.rm=T))
    t_exportaciones14<- t_exportaciones2014 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_52<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_52,sheet = "9",t_exportaciones14, startCol = 4,startRow = 12,colNames = F) ##escribir
    tabulado9_52 <- saveWorkbook(wb9_52,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeventas9 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven9 <- bd_dieeventas9 %>% filter (anio == 2015 & situacion == 1)
t_ventas2015 <- d_dieeven9 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb96<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb96,sheet = "9",t_ventas2015, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado96 <- saveWorkbook(wb96,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2015 <- d_dieeven9 %>% summarise ("total_ventas"=sum((ventas_nacionales/141.490328484162)*100,na.rm=T))
    t_ventanacional15<- t_ventanacional2015 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_61<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_61,sheet = "9",t_ventanacional15, startCol = 3,startRow = 13,colNames = F) ##escribir
    tabulado9_61 <- saveWorkbook(wb9_61,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2015 <- d_dieeven9 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/141.490328484162)*100,na.rm=T))
    t_exportaciones15<- t_exportaciones2015 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_62<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_62,sheet = "9",t_exportaciones15, startCol = 4,startRow = 13,colNames = F) ##escribir
    tabulado9_62 <- saveWorkbook(wb9_62,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeventas10 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven10 <- bd_dieeventas10 %>% filter (anio == 2016 & situacion == 1)
t_ventas2016 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb97<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb97,sheet = "9",t_ventas2016, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado97 <- saveWorkbook(wb97,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2016 <- d_dieeven10 %>% summarise ("total_ventas"=sum((ventas_nacionales/144.180974753378)*100,na.rm=T))
    t_ventanacional16<- t_ventanacional2016 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_71<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_71,sheet = "9",t_ventanacional16, startCol = 3,startRow = 14,colNames = F) ##escribir
    tabulado9_71 <- saveWorkbook(wb9_71,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2016 <- d_dieeven10 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/144.180974753378)*100,na.rm=T))
    t_exportaciones16<- t_exportaciones2016 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_72<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_72,sheet = "9",t_exportaciones16, startCol = 4,startRow = 14,colNames = F) ##escribir
    tabulado9_72 <- saveWorkbook(wb9_72,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeventas101 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven10 <- bd_dieeventas101 %>% filter (anio == 2017 & situacion == 1)
t_ventas2017 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb971<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb971,sheet = "9",t_ventas2017, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado97 <- saveWorkbook(wb971,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2017 <- d_dieeven10 %>% summarise ("total_ventas"=sum((ventas_nacionales/146.987310714795)*100,na.rm=T))
    t_ventanacional17<- t_ventanacional2017 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_711<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_711,sheet = "9",t_ventanacional17, startCol = 3,startRow = 15,colNames = F) ##escribir
    tabulado9_711 <- saveWorkbook(wb9_711,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2017 <- d_dieeven10 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/146.987310714795)*100,na.rm=T))
    t_exportaciones17 <- t_exportaciones2017 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_722<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_722,sheet = "9",t_exportaciones17, startCol = 4,startRow = 15,colNames = F) ##escribir
    tabulado9_722 <- saveWorkbook(wb9_722,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeventas11 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven11 <- bd_dieeventas11 %>% filter (anio == 2018 & situacion == 1)
t_ventas2018 <- d_dieeven11 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.660824062251)*100,na.rm=T))

#Exportar resultados a excel
wb98<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb98,sheet = "9",t_ventas2018, startCol = 1,startRow = 16,colNames = F) ##escribir
tabulado98 <- saveWorkbook(wb98,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2018 <- d_dieeven11 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.660824062251)*100,na.rm=T))
    t_ventanacional18<- t_ventanacional2018 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_81<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_81,sheet = "9",t_ventanacional18, startCol = 3,startRow = 16,colNames = F) ##escribir
    tabulado9_81 <- saveWorkbook(wb9_81,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2018 <- d_dieeven11 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.660824062251)*100,na.rm=T))
    t_exportaciones18 <- t_exportaciones2018 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_82<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_82,sheet = "9",t_exportaciones18, startCol = 4,startRow = 16,colNames = F) ##escribir
    tabulado9_82 <- saveWorkbook(wb9_82,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2019
bd_dieeventas12 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven12 <- bd_dieeventas12 %>% filter (anio == 2019 & situacion == 1)
t_ventas2019 <- d_dieeven12 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.404773038192)*100,na.rm=T))

#Exportar resultados a excel
wb99<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb99,sheet = "9",t_ventas2019, startCol = 1,startRow = 17,colNames = F) ##escribir
addStyle(wb99,"9",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb99,"9",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado99 <- saveWorkbook(wb99,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2019 <- d_dieeven12 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.404773038192)*100,na.rm=T))
    t_ventanacional19 <- t_ventanacional2019 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb9_91<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_91,sheet = "9",t_ventanacional19, startCol = 3,startRow = 17,colNames = F) ##escribir
    tabulado9_91 <- saveWorkbook(wb9_91,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2019 <- d_dieeven12 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.404773038192)*100,na.rm=T))
    t_exportaciones19 <- t_exportaciones2019 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb9_92<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb9_92,sheet = "9",t_exportaciones19, startCol = 4,startRow = 17,colNames = F) ##escribir
    tabulado9_92 <- saveWorkbook(wb9_92,"Tabulados_DIEE_2019.xlsx",overwrite = T)

######################TABULADO 10##################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#              ANIO 2019 POR FORMA INSTITUCIONAL                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

# Calculo de las variables.
t_participacion <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_participacion$total_ventas,na.rm =T )
t_participacion$porcentaje <- t_participacion$total_ventas / total

#Lectura catalogo de variables.
des_participacion <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_participacion,t_participacion,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb10<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb10,sheet = "10","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb10,sheet = "10",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb10,sheet = "10",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb10,sheet = "10",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb10,"10",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb10,"10",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado10 <- saveWorkbook(wb10,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#############################TABULADO 11#########################################
#   VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2019   #
#                        POR TAMANO DE EMPRESA                                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanop_plazas,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_tamanoventas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoventas$total_ventas,na.rm =T )
t_tamanoventas$porcentaje <- t_tamanoventas$total_ventas / total

#Lectura catalogo de variables.
des_tamanoventas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoventas,t_tamanoventas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb11<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb11,sheet = "11","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb11,sheet = "11",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb11,sheet = "11",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb11,sheet = "11",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb11,"11",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb11,"11",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb11,"11",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado11 <- saveWorkbook(wb11,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#####################TABULADO 12####################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#            ANIO 2019 POR SECTOR ECONOMICO                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_sectorventas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectorventas$total_ventas,na.rm =T )
t_sectorventas$porcentaje <- t_sectorventas$total_ventas / total

#Lectura catalogo de variables.
des_sectorventas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorventas,t_sectorventas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb12<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb12,sheet = "12","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb12,sheet = "12",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb12,sheet = "12",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb12,sheet = "12",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb12,"12",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb12,"12",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado12 <- saveWorkbook(wb12,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###################TABULADO 13###################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),#
#       ANIO 2019 POR ACTIVIDAD ECONOMICA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_seccventas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb13<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb13,sheet = "13","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb13,sheet = "13",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb13,sheet = "13",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb13,sheet = "13",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb13,"13",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb13,"13",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado13 <- saveWorkbook(wb13,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 14###############################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),#
#          ANIO 2019 POR PROVINCIA                           #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_provventas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provventas$total_ventas,na.rm =T )
t_provventas$porcentaje <- t_provventas$total_ventas / total

#Lectura catalogo de variables.
des_provventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provventas,t_provventas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb14<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb14,sheet = "14","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb14,sheet = "14",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb14,sheet = "14",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb14,sheet = "14",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb14,"14",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb14,"14",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado14 <- saveWorkbook(wb14,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########SECCION III: plazas de empleo registrado, empleo registrado y masa salarial##################

###############TABULADO 15####################################
#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006-2019#

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006 - 2011 POR ANIO
d_plazas <- bd_diee1 %>% select(plazas,plazas_hombres,plazas_mujeres,anio,situacion)

#total empresas del año 2006-2011#
t_plazas <- d_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                  "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                  "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb15<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb15,"15",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb15,"15",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado15 <- saveWorkbook(wb15,"Tabulados_DIEE_2019.xlsx",overwrite = T)

########PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2019 POR ANIO

bd_plazas <- bd_diee %>% select(plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas1 <- bd_plazas %>% filter (situacion ==1)

#total empresas del año 2012-2019#
t_plazas <- bd_plazas1 %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                     "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                     "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb151<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb151,"15",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb151,"15",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado151 <- saveWorkbook(wb151,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#######################TABULADO 16##################################################
#############PLAZAS DE EMPLEO REGISTRADO (UNIVERSO DIEE), POR RANGO DE EDAD AO 2019

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_plazas <- bd_dieeact %>% select(plazas_rango_edad_1,plazas_rango_edad_2,
                                   plazas_rango_edad_3,plazas_rango_edad_4, 
                                   plazas_rango_edad_5, situacion)

#Calculo de las variables.
t_plazasre1 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_1,na.rm=T), porcentaje = 0)
t_plazasre2 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_2,na.rm=T), porcentaje = 0)
t_plazasre3 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_3,na.rm=T), porcentaje = 0)
t_plazasre4 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_4,na.rm=T), porcentaje = 0)
t_plazasre5 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_plazasre1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_plazasre2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_plazasre3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_plazasre4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_plazasre5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_plazas,na.rm = T)
tabla1$porcentaje <- tabla1$total_plazas/total

#Exportar resultados a excel
wb16<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb16,sheet = "16","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb16,sheet = "16",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb16,sheet = "16",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb16,sheet = "16",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb16,"16",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb16,"16",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb16,"16",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado16 <- saveWorkbook(wb16,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#######################TABULADO 17#############################################
#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), ANIO 2019 POR FORMA INSTITUCIONAL#

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_plazas <- bd_dieeact %>% select(plazas,forma_institucional,situacion)

#Calculo de las variables.
t_plazasins <- bd_plazas %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb17<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb17,sheet = "17","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb17,sheet = "17",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb17,sheet = "17",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb17,sheet = "17",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb17,"17",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb17,"17",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado17 <- saveWorkbook(wb17,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##############################TABULADO 18##############################################
##PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2019 POR TAMANO DE EMPRESA#

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanop_plazas,plazas,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_tamanoplazas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoplazas$total_plazas,na.rm =T )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_plazas / total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb18<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb18,sheet = "18","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb18,sheet = "18",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb18,sheet = "18",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb18,sheet = "18",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb18,"18",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb18,"18",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb18,"18",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado18 <- saveWorkbook(wb18,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###########################TABULADO 19###############################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2019 POR SECTOR ECONOMICO#

#seleccion de variables###
df1 <- bd_diee %>% select(gsectores,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_sectorplazas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_sectorplazas$total_plazas,na.rm =T )
t_sectorplazas$porcentaje <- t_sectorplazas$total_plazas / total

#Lectura catalogo de variables.
des_sectorplazas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorplazas,t_sectorplazas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb19<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb19,sheet = "19","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb19,sheet = "19",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb19,sheet = "19",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb19,sheet = "19",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb19,"19",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb19,"19",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado19 <- saveWorkbook(wb19,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###########################TABULADO 20##############################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#            ANIO 2019 POR ACTIVIDAD ECONOMICA                     #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#calculo#
t_seccplazas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_seccplazas$total_plazas,na.rm =T )
t_seccplazas$porcentaje <- t_seccplazas$total_plazas / total

#Lectura catalogo de variables.
des_seccplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccplazas,t_seccplazas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb20<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb20,sheet = "20","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb20,sheet = "20",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb20,sheet = "20",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb20,sheet = "20",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb20,"20",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb20,"20",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado20 <- saveWorkbook(wb20,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##############################TABULADO 21############################
#  PERSONAL AFILIADO SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),  #  
#                     ANIO 2019 POR PROVINCIA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_provplazas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_provplazas$total_plazas,na.rm =T )
t_provplazas$porcentaje <- t_provplazas$total_plazas / total

#Lectura catalogo de variables.
des_provplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provplazas,t_provplazas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb21<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb21,sheet = "21","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb21,sheet = "21",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb21,sheet = "21",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb21,sheet = "21",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb21,"21",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb21,"21",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado21 <- saveWorkbook(wb21,"Tabulados_DIEE_2019.xlsx",overwrite = T)

########TABULADO 22##############################################
#PERSONAL AFILIADO - EMPLEO (UNIVERSO DIEE), PERIODO 2006 - 2019 POR ANIO#

#BASE GENERAL 2006 - 2011
d_empleo <- bd_diee1 %>% select(empleo,empleo_hombres,empleo_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_empleoafi <- d_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                     "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                     "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb22<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb22,sheet = "22",t_empleoafi, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb22,"22",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb22,"22",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado22 <- saveWorkbook(wb22,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#BASE GENERAL 2012-2019
bd_empleo2 <- bd_diee %>% select(empleo,empleo_hombres,empleo_mujeres,ventas_totales,anio,situacion)
bd_empleo2 <- bd_empleo2 %>% filter (situacion ==1)

#total empresas del anio 2012-2019#
t_empleoafi <- bd_empleo2 %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                    "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                    "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb222<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb222,sheet = "22",t_empleoafi, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb222,"22",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb222,"22",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado222 <- saveWorkbook(wb222,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 23#######################################
#EMPLEO REGISTRADO (UNIVERSO DIEE), AO 2019 POR RANGO DE EDAD#
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_empleo <- bd_dieeact %>% select(empleo_rango_edad_1,empleo_rango_edad_2,
                                   empleo_rango_edad_3,empleo_rango_edad_4, 
                                   empleo_rango_edad_5, situacion)

#Calculo de las variables.
t_empleore1 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_1,na.rm=T), porcentaje = 0)
t_empleore2 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_2,na.rm=T), porcentaje = 0)
t_empleore3 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_3,na.rm=T), porcentaje = 0)
t_empleore4 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_4,na.rm=T), porcentaje = 0)
t_empleore5 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_empleore1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_empleore2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_empleore3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_empleore4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_empleore5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_empleo,na.rm = T)
tabla1$porcentaje <- tabla1$total_empleo/total

#Exportar resultados a excel
wb23<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb23,sheet = "23","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb23,sheet = "23",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb23,sheet = "23",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb23,sheet = "23",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb23,"23",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb23,"23",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb23,"23",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado23 <- saveWorkbook(wb23,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 24#######################################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2019 POR FORMA INSTITUCIONAL# 

#Filtrar empresas activas del año del cual se requiere
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_empleo <- bd_dieeact %>% select(empleo,forma_institucional,situacion)

#Calculo de las variables.
t_empformains <- bd_empleo %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_empformains$total_empleo,na.rm =T )
t_empformains$porcentaje <- t_empformains$total_empleo / total

#Lectura catalogo de variables.
des_empformainst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empformainst,t_empformains,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb24<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb24,sheet = "24","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb24,sheet = "24",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb24,sheet = "24",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb24,sheet = "24",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb24,"24",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb24,"24",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado24 <- saveWorkbook(wb24,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###########################TABULADO 25#################################################
# PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2019 POR TAMANO DE EMPRESA#

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_empleo,empleo,anio,situacion)
#Seleccion de variables que se requieren para el tabulado.
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanop_empleo) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo / total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanop_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb25<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb25,sheet = "25","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb25,sheet = "25",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb25,sheet = "25",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb25,sheet = "25",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb25,"25",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb25,"25",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb25,"25",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado25 <- saveWorkbook(wb25,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###################################TABULADO 26#######################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2019 POR SECTOR ECONOMICO#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo / total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb26<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb26,sheet = "26","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb26,sheet = "26",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb26,sheet = "26",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb26,sheet = "26",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb26,"26",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb26,"26",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado26 <- saveWorkbook(wb26,"Tabulados_DIEE_2019.xlsx",overwrite = T)

######################TABULADO 27##################################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)# 
#         ANIO 2019 POR ACTIVIDAD ECONOMICA                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_seccempleo <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_seccempleo$total_empleo,na.rm =T )
t_seccempleo$porcentaje <- t_seccempleo$total_empleo / total

#Lectura catalogo de variables.
des_seccempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccempleo,t_seccempleo,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb27<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb27,sheet = "27","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb27,sheet = "27",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb27,sheet = "27",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb27,sheet = "27",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb27,"27",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb27,"27",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado27 <- saveWorkbook(wb27,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########TABULADO 28##########################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2019#
#           POR PROVINCIA                    #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb28<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb28,sheet = "28","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb28,sheet = "28",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb28,sheet = "28",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb28,sheet = "28",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb28,"28",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb28,"28",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado28 <- saveWorkbook(wb28,"Tabulados_DIEE_2019.xlsx",overwrite = T)

################################TABULADO 29##########################################
#       MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2019 POR ANIO                 #

#BASE GENERAL 2006-2011
d_remuneracion <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_remuneraciones <- d_remuneracion %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb29<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb29,sheet = "29",t_remuneraciones, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb29,"29",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb29,"29",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado29 <- saveWorkbook(wb29,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#BASE GENERAL 2012-2019
d_remuneracion <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_remuneracion1 <- d_remuneracion %>% filter(situacion ==1)

#total empresas del año 2012-2019#
t_remuneraciones <- d_remuneracion1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                    "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                    "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb291<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb291,sheet = "29",t_remuneraciones, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb291,"29",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb291,"29",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado291 <- saveWorkbook(wb291,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#################TABULADO 30 : CONSTANTES#################################
#MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2019 POR ANIO#

#lectura de base 2006
bd_dieems <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems1 <- bd_dieems %>% filter (anio == 2006 & situacion == 1)
t_masa2006 <- d_dieems1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/96.78695716)*100,na.rm=T),
                                                  "total_remuneracioneshombres" =sum((remuneraciones_hombres/96.7869571635269)*100,na.rm=T),
                                                  "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/96.78695716)*100,na.rm=T))
#Exportar resultados a excel
wb30<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb30,sheet = "30",t_masa2006, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado30 <- saveWorkbook(wb30,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2007
bd_dieems1 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems2 <- bd_dieems1 %>% filter (anio == 2007 & situacion == 1)
t_masa2007 <- d_dieems2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/100.0000000)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/100.0000000)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/100.0000000)*100,na.rm=T))
#Exportar resultados a excel
wb301<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb301,sheet = "30",t_masa2007, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado301 <- saveWorkbook(wb301,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2008
bd_dieems2 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems3 <- bd_dieems2 %>% filter (anio == 2008 & situacion == 1)
t_masa2008 <- d_dieems3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/108.83054136472500)*100,na.rm=T))
#Exportar resultados a excel
wb302<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb302,sheet = "30",t_masa2008, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado302 <- saveWorkbook(wb302,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2009
bd_dieems3 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems4 <- bd_dieems3 %>% filter (anio == 2009 & situacion == 1)
t_masa2009 <- d_dieems4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/113.5230353096400)*100,na.rm=T))
#Exportar resultados a excel
wb303<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb303,sheet = "30",t_masa2009, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado303 <- saveWorkbook(wb303,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2010
bd_dieems4 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems5 <- bd_dieems4 %>% filter (anio == 2010 & situacion == 1)
t_masa2010 <- d_dieems5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/117.3011217423320)*100,na.rm=T))
#Exportar resultados a excel
wb304<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb304,sheet = "30",t_masa2010, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado304 <- saveWorkbook(wb304,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2011
bd_dieems5 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems6 <- bd_dieems5 %>% filter (anio == 2011 & situacion == 1)
t_masa2011 <- d_dieems6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb305<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb305,sheet = "30",t_masa2011, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado305 <- saveWorkbook(wb305,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2012
bd_dieems6 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems7 <- bd_dieems6 %>% filter (anio == 2012 & situacion == 1)
t_masa2012 <- d_dieems7 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb306<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb306,sheet = "30",t_masa2012, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado306 <- saveWorkbook(wb306,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2013
bd_dieems7 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems8 <- bd_dieems7 %>% filter (anio == 2013 & situacion == 1)
t_masa2013 <- d_dieems8 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb307<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb307,sheet = "30",t_masa2013, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado307 <- saveWorkbook(wb307,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2014
bd_dieems8 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems9 <- bd_dieems8 %>% filter (anio == 2014 & situacion == 1)
t_masa2014 <- d_dieems9 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb308<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb308,sheet = "30",t_masa2014, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado308 <- saveWorkbook(wb308,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2015
bd_dieems9 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems10 <- bd_dieems9 %>% filter (anio == 2015 & situacion == 1)
t_masa2015 <- d_dieems10 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb309<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb309,sheet = "30",t_masa2015, startCol = 1,startRow = 16,colNames = F) ##escribir
tabulado309 <- saveWorkbook(wb309,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2016
bd_dieems10 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems11 <- bd_dieems10 %>% filter (anio == 2016 & situacion == 1)
t_masa2016 <- d_dieems11 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb3010<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb3010,sheet = "30",t_masa2016, startCol = 1,startRow = 17,colNames = F) ##escribir
tabulado3010 <- saveWorkbook(wb3010,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2017
bd_dieems11 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems12 <- bd_dieems11 %>% filter (anio == 2017 & situacion == 1)
t_masa2017 <- d_dieems12 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb3011<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb3011,sheet = "30",t_masa2017, startCol = 1,startRow = 18,colNames = F) ##escribir
addStyle(wb3011,"30",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3011,"30",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3011 <- saveWorkbook(wb3011,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2018
bd_dieems12 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems121 <- bd_dieems12 %>% filter (anio == 2018 & situacion == 1)
t_masa2018 <- d_dieems121 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                            "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                            "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb3012<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb3012,sheet = "30",t_masa2018, startCol = 1,startRow = 19,colNames = F) ##escribir
addStyle(wb3012,"30",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3012,"30",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3012 <- saveWorkbook(wb3012,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2019
bd_dieems13 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems122 <- bd_dieems13 %>% filter (anio == 2019 & situacion == 1)
t_masa2019 <- d_dieems122 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.344842799337)*100,na.rm=T))
#Exportar resultados a excel
wb3013<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb3013,sheet = "30",t_masa2019, startCol = 1,startRow = 20,colNames = F) ##escribir
addStyle(wb3013,"30",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3013,"30",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3013 <- saveWorkbook(wb3013,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#######################TABULADO 31################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#              ANIO 2019 POR FORMA INSTITUCIONAL                 #

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_remuneraciones <- bd_dieeact %>% select(remuneraciones,forma_institucional,situacion)

#calculo#
t_remuneracionesins <- bd_remuneraciones %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb31<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb31,sheet = "31","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb31,sheet = "31",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb31,sheet = "31",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb31,sheet = "31",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb31,"31",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb31,"31",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado31 <- saveWorkbook(wb31,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##########################TABULADO 32##################################
###   MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) ### 
###              ANIO 2019 POR TAMANO DE EMPRESA                    ###

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_plazas,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 )

#calculo#
t_tamanoremu <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb32<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb32,sheet = "32","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb32,sheet = "32",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb32,sheet = "32",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb32,sheet = "32",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb32,"32",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb32,"32",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb32,"32",grisStyle,cols= 5:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado32 <- saveWorkbook(wb32,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#############################TABULADO 33#########################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#           ANIO 2019 POR SECTOR ECONOMICO                      #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#calculo#
t_sectorremu<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total
                            
#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb33<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb33,sheet = "33","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb33,sheet = "33",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb33,sheet = "33",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb33,sheet = "33",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb33,"33",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb33,"33",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado33 <- saveWorkbook(wb33,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###########################TABULADO 34############################
##MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),## 
#              ANIO 2019 POR ACTIVIDAD ECONOMICA                 #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_seccremu <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccremu$total_remu,na.rm =T )
t_seccremu$porcentaje <- t_seccremu$total_remu / total

#Lectura catalogo de variables.
des_seccremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccremu,t_seccremu,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb34<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb34,sheet = "34","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb34,sheet = "34",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb34,sheet = "34",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb34,sheet = "34",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb34,"34",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb34,"34",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado34 <- saveWorkbook(wb34,"Tabulados_DIEE_2019.xlsx",overwrite = T)

######################TABULADO 35####################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019 POR PROVINCIA#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 )

#Calculo de las variables.
t_provremu <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provremu$total_remu,na.rm =T )
t_provremu$porcentaje <- t_provremu$total_remu / total

#Lectura catalogo de variables.
des_provremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provremu,t_provremu,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb35<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb35,sheet = "35","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb35,sheet = "35",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb35,sheet = "35",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb35,sheet = "35",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb35,"35",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb35,"35",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado35 <- saveWorkbook(wb35,"Tabulados_DIEE_2019.xlsx",overwrite = T)

######EMPRESAS QUE REGISTRAN VENTAS Y EMPLEO DE ACTIVIDADES PRODUCTIVAS (SE EXCLUYE SECCIONES O,P,Q)**#####
#########SECCION IV: número de empresas, ventas, plazas de empleo, empleo registrado y masa salarial##################

###########################TABULADO 36###############################################
#TOTAL EMPRESAS (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2019 POR ANIO#

#BASE GENERAL 2011 
#Seleccion de variables que se requieren para el tabulado.
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
d_act1 <- d_act %>% filter(situacion == 1 & estructura_estrat == 1 & anio== 2011)

#total empresas del año 2006-2011#
t_actprod <- d_act1 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb36<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb36,sheet = "36",t_actprod, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb36,"36",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb36,"36",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado36 <- saveWorkbook(wb36,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#BASE GENERAL 2012-2019
d_act <- bd_diee %>% select(estructura_estrat,codigo_seccion,anio,situacion)
d_act2<- d_act %>% filter(situacion ==1 & estructura_estrat ==1 )

#total empresas del año 2012-2019
t_actprod2 <- d_act2 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb361<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb361,sheet = "36",t_actprod2, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb361,"36",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb361,"36",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado361 <- saveWorkbook(wb361,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##################################TABULADO 37####################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2019 POR FORMA INSTITUCIONAL                                #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,forma_institucional,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_actfi <- bd_dieeact %>% group_by (forma_institucional) %>% summarise ("total_actfi"= n(), porcentaje = 0)
total <- sum(t_actfi$total_actfi,na.rm =T )
t_actfi$porcentaje <- t_actfi$total_actfi / total

#Lectura catalogo de variables.
des_actfi <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_actfi,t_actfi,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_actfi,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb37<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb37,sheet = "37","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb37,sheet = "37",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb37,sheet = "37",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb37,sheet = "37",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb37,"37",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb37,"37",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado37 <- saveWorkbook(wb37,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###############################TABULADO 38#######################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2019 POR TAMANO DE EMPRESAS                          #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,tamanop_plazas,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_tamanoat<- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_at"= n(), porcentaje = 0)
total <- sum(t_tamanoat$total_at,na.rm =T )
t_tamanoat$porcentaje <- t_tamanoat$total_at / total

#Lectura catalogo de variables.
des_tamanoat <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoat,t_tamanoat,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_at,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb38<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb38,sheet = "38","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb38,sheet = "38",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb38,sheet = "38",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb38,sheet = "38",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb38,"38",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb38,"38",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb38,"38",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado38 <- saveWorkbook(wb38,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#################TABULADO 39######################################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#           ANIO 2019 POR SECTOR ECONOMICO                                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_sectorap<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_sectorap$total_ap,na.rm =T )
t_sectorap$porcentaje <- t_sectorap$total_ap / total

#Lectura catalogo de variables.
des_sectorap <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorap,t_sectorap,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb39<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb39,sheet = "39","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb39,sheet = "39",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb39,sheet = "39",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb39,sheet = "39",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb39,"39",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb39,"39",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado39 <- saveWorkbook(wb39,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 40#############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2019, POR ACTIVIDAD ECONOMICA                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccap<- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_seccap$total_ap,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ap / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb40<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb40,sheet = "40","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb40,sheet = "40",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb40,sheet = "40",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb40,sheet = "40",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb40,"40",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb40,"40",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado40 <- saveWorkbook(wb40,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#######################TABULADO 41###############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2019 POR PROVINCIA                                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_provap$total_ap,na.rm =T )
t_provap$porcentaje <- t_provap$total_ap / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb41 <-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb41,sheet = "41","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb41,sheet = "41",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb41,sheet = "41",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb41,sheet = "41",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb41,"41",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb41,"41",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado41 <- saveWorkbook(wb41,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##########################TABULADO 42####################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)  #       
#             PERIODO 2011 - 2019 POR ANIO              #

#Seleccion de variables que se requieren para el tabulado.
##BASE GENERAL 2011###
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_excact <- d_act %>% filter (estructura_estrat == 1, situacion ==1 , anio ==2011)

#total empresas del año 2006-2011#
t_actprod1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb42<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb42,sheet = "42",t_actprod1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb42,"42",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb42,"42",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado42 <- saveWorkbook(wb42,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    #total empresas del ao 2009 - 2011#
    t_nacional1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
    t_nacional2 <- t_nacional1 %>% select(total_ventanacional)
    
    #Exportar resultados a excel
    wb42_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb42_1,sheet = "42",t_nacional2, startCol = 3,startRow = 7,colNames = F) ##escribir
    tabulado42_1 <- saveWorkbook(wb42_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    #total empresas del ao 2009 - 2011#
    t_expprod1 <- d_excact %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
    t_expprod2 <- t_expprod1 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb42_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb42_2,sheet = "42",t_expprod2, startCol = 4,startRow = 7,colNames = F) ##escribir
    tabulado42_2 <- saveWorkbook(wb42_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##BASE GENERAL 2012-2019###
d_act1 <- bd_diee %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_excact <- d_act1 %>% filter (estructura_estrat == 1, situacion ==1 )

#total empresas del año 2012-2019#
t_actprod <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb421<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb421,sheet = "42",t_actprod, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb421,"42",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb421,"42",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado421 <- saveWorkbook(wb421,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    #total empresas del ao 2012 - 2019#
    t_vntanacional1_1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
    t_vntanacional2_2 <- t_vntanacional1_1 %>% select(total_ventanacional)
    
    #Exportar resultados a excel
    wb422<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb422,sheet = "42",t_vntanacional2_2, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado422 <- saveWorkbook(wb422,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    #total empresas del ao 2012 - 2019#
    t_exp1_1 <- d_excact %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
    t_exp2_2 <- t_exp1_1 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_33<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_33,sheet = "42",t_exp2_2, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado4_33 <- saveWorkbook(wb4_33,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#####################TABULADO 43 (CONSTANTES)################################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2019##

#lectura de base 2011
bd_dieeap <- bd_diee1 %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap <- bd_dieeap %>% filter (anio == 2011 & situacion == 1&estructura_estrat==1)
t_ventas2011 <- d_dieeap %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb43<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb43,sheet = "43",t_ventas2011, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado43 <- saveWorkbook(wb43,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2011 <- d_dieeap %>% summarise ("total_ventas"=sum((ventas_nacionales/130.12159330682)*100,na.rm=T))
    t_vntnacional11<- t_vntnacional2011 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_3_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_3_1,sheet = "43",t_vntnacional11, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado4_3_1 <- saveWorkbook(wb4_3_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2011 <- d_dieeap %>% summarise ("total_exportaciones"=sum((exportaciones_netas/130.12159330682)*100,na.rm=T))
    t_export11 <- t_export2011 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_3_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_3_2,sheet = "43",t_export11, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado4_3_2 <- saveWorkbook(wb4_3_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeap1 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap1 <- bd_dieeap1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat==1)
t_ventas2012 <- d_dieeap1 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb431<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb431,sheet = "43",t_ventas2012, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado431 <- saveWorkbook(wb431,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2012 <- d_dieeap1 %>% summarise ("total_ventas"=sum((ventas_nacionales/136.608484020484)*100,na.rm=T))
    t_vntnacional12<- t_vntnacional2012 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_4_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_4_1,sheet = "43",t_vntnacional12, startCol = 3,startRow = 9,colNames = F) ##escribir
    tabulado4_4_1 <- saveWorkbook(wb4_4_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2012 <- d_dieeap1 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/136.608484020484)*100,na.rm=T))
    t_export12 <- t_export2012 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_4_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_4_2,sheet = "43",t_export12, startCol = 4,startRow = 9,colNames = F) ##escribir
    tabulado4_4_2 <- saveWorkbook(wb4_4_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeap2 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap2 <- bd_dieeap2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat==1)
t_ventas2013 <- d_dieeap2 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb432<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb432,sheet = "43",t_ventas2013, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado432 <- saveWorkbook(wb432,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2013 <- d_dieeap2 %>% summarise ("total_ventas"=sum((ventas_nacionales/140.836583556647)*100,na.rm=T))
    t_vntnacional13<- t_vntnacional2013 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_5_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_5_1,sheet = "43",t_vntnacional13, startCol = 3,startRow = 10,colNames = F) ##escribir
    tabulado4_5_1 <- saveWorkbook(wb4_5_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2013 <- d_dieeap2 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/140.836583556647)*100,na.rm=T))
    t_export13 <- t_export2013 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_5_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_5_2,sheet = "43",t_export13, startCol = 4,startRow = 10,colNames = F) ##escribir
    tabulado4_5_2 <- saveWorkbook(wb4_5_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeap3 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap3 <- bd_dieeap3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat==1)
t_ventas2014 <- d_dieeap3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb433<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb433,sheet = "43",t_ventas2014, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado433 <- saveWorkbook(wb433,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2014 <- d_dieeap3 %>% summarise ("total_ventas"=sum((ventas_nacionales/145.104922216934)*100,na.rm=T))
    t_vntnacional14<- t_vntnacional2014 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_6_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_6_1,sheet = "43",t_vntnacional14, startCol = 3,startRow = 11,colNames = F) ##escribir
    tabulado4_6_1 <- saveWorkbook(wb4_6_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2014 <- d_dieeap3 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/145.104922216934)*100,na.rm=T))
    t_export14 <- t_export2014 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_6_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_6_2,sheet = "43",t_export14, startCol = 4,startRow = 11,colNames = F) ##escribir
    tabulado4_6_2 <- saveWorkbook(wb4_6_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeap4 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap4 <- bd_dieeap4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat==1)
t_ventas2015 <- d_dieeap4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb434<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb434,sheet = "43",t_ventas2015, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado434 <- saveWorkbook(wb434,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2015 <- d_dieeap4 %>% summarise ("total_ventas"=sum((ventas_nacionales/141.490328484162)*100,na.rm=T))
    t_vntnacional15<- t_vntnacional2015 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_7_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_7_1,sheet = "43",t_vntnacional15, startCol = 3,startRow = 12,colNames = F) ##escribir
    tabulado4_7_1 <- saveWorkbook(wb4_7_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2015 <- d_dieeap4 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/141.490328484162)*100,na.rm=T))
    t_export15 <- t_export2015 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_7_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_7_2,sheet = "43",t_export15, startCol = 4,startRow = 12,colNames = F) ##escribir
    tabulado4_7_2 <- saveWorkbook(wb4_7_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeap5 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap5 <- bd_dieeap5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat==1)
t_ventas2016 <- d_dieeap5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb435<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb435,sheet = "43",t_ventas2016, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado435 <- saveWorkbook(wb435,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2016 <- d_dieeap5 %>% summarise ("total_ventas"=sum((ventas_nacionales/144.180974753378)*100,na.rm=T))
    t_vntnacional16<- t_vntnacional2016 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_8_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_8_1,sheet = "43",t_vntnacional16, startCol = 3,startRow = 13,colNames = F) ##escribir
    tabulado4_8_1 <- saveWorkbook(wb4_8_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2016 <- d_dieeap5 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/144.180974753378)*100,na.rm=T))
    t_export16 <- t_export2016 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_8_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_8_2,sheet = "43",t_export16, startCol = 4,startRow = 13,colNames = F) ##escribir
    tabulado4_8_2 <- saveWorkbook(wb4_8_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeap6 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap6 <- bd_dieeap6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat==1)
t_ventas2017 <- d_dieeap6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb436<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb436,sheet = "43",t_ventas2017, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb436,"43",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb436,"43",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado436 <- saveWorkbook(wb436,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2017 <- d_dieeap6 %>% summarise ("total_ventas"=sum((ventas_nacionales/146.987310714795)*100,na.rm=T))
    t_vntnacional17<- t_vntnacional2017 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_9_1,sheet = "43",t_vntnacional17, startCol = 3,startRow = 14,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2017 <- d_dieeap6 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/146.987310714795)*100,na.rm=T))
    t_export17 <- t_export2017 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_9_2,sheet = "43",t_export17, startCol = 4,startRow = 14,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeap7 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap7 <- bd_dieeap7 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat==1)
t_ventas2018 <- d_dieeap7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.660824062251)*100,na.rm=T))

#Exportar resultados a excel
wb437<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb437,sheet = "43",t_ventas2018, startCol = 1,startRow = 15,colNames = F) ##escribir
addStyle(wb437,"43",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb437,"43",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado437 <- saveWorkbook(wb437,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2018 <- d_dieeap7 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.660824062251)*100,na.rm=T))
    t_vntnacional18<- t_vntnacional2018 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_10_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_10_1,sheet = "43",t_vntnacional18, startCol = 3,startRow = 15,colNames = F) ##escribir
    tabulado4_10_1 <- saveWorkbook(wb4_10_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2018 <- d_dieeap7 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.660824062251)*100,na.rm=T))
    t_export18 <- t_export2018 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_10_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_10_2,sheet = "43",t_export18, startCol = 4,startRow = 15,colNames = F) ##escribir
    tabulado4_10_2 <- saveWorkbook(wb4_10_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2019
bd_dieeap8 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap8 <- bd_dieeap8 %>% filter (anio == 2019 & situacion == 1 & estructura_estrat==1)
t_ventas2019 <- d_dieeap8 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.404773038192)*100,na.rm=T))

#Exportar resultados a excel
wb438<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb438,sheet = "43",t_ventas2019, startCol = 1,startRow = 16,colNames = F) ##escribir
addStyle(wb438,"43",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb438,"43",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado438 <- saveWorkbook(wb438,"Tabulados_DIEE_2019.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2019 <- d_dieeap8 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.404773038192)*100,na.rm=T))
    t_vntnacional19<- t_vntnacional2019 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_11_1<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_11_1,sheet = "43",t_vntnacional19, startCol = 3,startRow = 16,colNames = F) ##escribir
    tabulado4_11_1 <- saveWorkbook(wb4_11_1,"Tabulados_DIEE_2019.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2019 <- d_dieeap8 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.404773038192)*100,na.rm=T))
    t_export19 <- t_export2019 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_11_2<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
    writeData(wb4_11_2,sheet = "43",t_export19, startCol = 4,startRow = 16,colNames = F) ##escribir
    tabulado4_11_2 <- saveWorkbook(wb4_11_2,"Tabulados_DIEE_2019.xlsx",overwrite = T)

################################TABULADO 44############################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2019 POR FORMA INSTITUCIONAL                             #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccventas <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb44<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb44,sheet = "44","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb44,sheet = "44",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb44,sheet = "44",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb44,sheet = "44",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb44,"44",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb44,"44",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado44 <- saveWorkbook(wb44,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#################################TABULADO 45###########################################
# VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS#
#                ANIO 2019 POR TAMANO DE  EMPRESA                                     #

#seleccion de variables###
bd_tamano <- bd_diee %>% select(tamanop_plazas,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_tamanovp <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_vp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanovp$total_vp,na.rm =T )
t_tamanovp$porcentaje <- t_tamanovp$total_vp/ total

#Lectura catalogo de variables.
des_tamanovp <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanovp,t_tamanovp,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb45<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb45,sheet = "45","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb45,sheet = "45",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb45,sheet = "45",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb45,sheet = "45",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb45,"45",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb45,"45",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb45,"45",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb45,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##################TABULADO 46##########################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                   ANIO 2019 POR SECTOR ECONOMICO                                    #

#seleccion de variables
bd_tamano <- bd_diee %>% select(gsectores,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_secvp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_secvp,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_secvp/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_secvp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb46<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb46,sheet = "46","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb46,sheet = "46",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb46,sheet = "46",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb46,sheet = "46",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb46,"46",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb46,"46",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb46,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##########################TABULADO 47##################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2019, POR ACTIVIDAD ECONOMICA                            # 

#seleccion de variables###
bd_tamano <- bd_diee %>% select(codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccap <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccap$total_ventas,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ventas / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb47<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb47,sheet = "47","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb47,sheet = "47",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb47,sheet = "47",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb47,sheet = "47",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb47,"47",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb47,"47",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb47,"Tabulados_DIEE_2019.xlsx",overwrite = T)

################################TABULADO 48##########################################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#                ANIO 2019 POR PROVINCIA                                            #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_ventas,na.rm =T )
t_provap$porcentaje <- t_provap$total_ventas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb48 <-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb48,sheet = "48","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb48,sheet = "48",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb48,sheet = "48",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb48,sheet = "48",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb48,"48",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb48,"48",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb48,"Tabulados_DIEE_2019.xlsx",overwrite = T)

########################TABULADO 49#################################
#PLAZAS DE EMPEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #                  
#                   PERIODO 2011 - 2019 POR ANIO                   #

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006-2011

d_plazas <- bd_diee1 %>% select(estructura_estrat,plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2019#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb49<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb49,sheet = "49",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb49,"49",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb49,"49",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb49,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2019 POR ANIO

d_plazas <- bd_diee %>% select(estructura_estrat,plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2019#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb491<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb491,sheet = "49",t_plazas, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb491,"49",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb491,"49",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb491,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################################TABULADO 50#############################
#    PLAZAS DE EMPLEO REGISTRADO SEGN PARTICIPACIN EN EL TOTAL           #
#    (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), AO 2019 POR RANGO DE EDAD    #

bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1 )

#seleccion de variables
bd_plazasrp <- bd_dieeact %>% select(plazas_rango_edad_1,plazas_rango_edad_2,
                                    plazas_rango_edad_3,plazas_rango_edad_4, 
                                    plazas_rango_edad_5,estructura_estrat,
                                    anio,situacion)


#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_plazasrp %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_plazasre1 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_1,na.rm=T), porcentaje = 0)
t_plazasre2 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_2,na.rm=T), porcentaje = 0)
t_plazasre3 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_3,na.rm=T), porcentaje = 0)
t_plazasre4 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_4,na.rm=T), porcentaje = 0)
t_plazasre5 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_plazasre1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_plazasre2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_plazasre3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_plazasre4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_plazasre5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_plazas,na.rm = T)
tabla1$porcentaje <- tabla1$total_plazas/total

#Exportar resultados a excel
wb50<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb50,sheet = "50","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb50,sheet = "50",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb50,sheet = "50",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb50,sheet = "50",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb50,"50",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb50,"50",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb50,"50",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb50,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################################TABULADO 51#############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL          #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR FORMA INSTITUCIONAL#

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,plazas,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_plazasins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb51<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb51,sheet = "51","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb51,sheet = "51",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb51,sheet = "51",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb51,sheet = "51",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb51,"51",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb51,"51",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb51,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#################################TABULADO 52###############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL         #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR TAMANO DE EMPRESA #

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanop_plazas,plazas,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_tamanoplazas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_vp"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoplazas$total_vp,na.rm =T )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_vp/ total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb52<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb52,sheet = "52","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb52,sheet = "52",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb52,sheet = "52",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb52,sheet = "52",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb52,"52",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb52,"52",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb52,"52",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb52,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#########################TABULADO 53######################################
#       PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL       #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR SECTOR ECONOMICO  #

#seleccion de variables
bd_sector <- bd_diee %>% select(gsectores,plazas,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_sector %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_plazas,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_plazas/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))
v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb53<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb53,sheet = "53","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb53,sheet = "53",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb53,sheet = "53",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb53,sheet = "53",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb53,"53",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb53,"53",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb53,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##############################TABULADO 54##################################
#   PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL            #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR ACTIVIDAD ECONOMICA#

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,plazas,estructura_estrat,anio,situacion)
bd_dieeact <- bd_act %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_plazas,na.rm =T )
t_secact$porcentaje <- t_secact$total_plazas / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb54<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb54,sheet = "54","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb54,sheet = "54",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb54,sheet = "54",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb54,sheet = "54",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb54,"54",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb54,"54",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb54,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 55######################################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION NACIONAL      #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR PROVINCIA   #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,plazas,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_plazas,na.rm =T )
t_provap$porcentaje <- t_provap$total_plazas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb55 <-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb55,sheet = "55","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb55,sheet = "55",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb55,sheet = "55",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb55,sheet = "55",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb55,"55",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb55,"55",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb55,"Tabulados_DIEE_2019.xlsx",overwrite = T)

######################## TABULADO 56 ##########################################
#EMPLEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2019#

# EMPLEO (UNIVERSO DIEE) PERIODO 2006-2011
#Seleccion de variables que se requieren para el tabulado.
d_empleo <- bd_diee1 %>% select(estructura_estrat,empleo,empleo_hombres,empleo_mujeres,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_empleo <- d_empleo %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2019#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb56<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb56,sheet = "56",t_empleo, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb56,"56",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb56,"56",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb56,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2019 POR ANIO

d_empleo <- bd_diee %>% select(estructura_estrat,empleo,empleo_hombres,empleo_mujeres,anio,situacion)
bd_empleo <- d_empleo %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2019#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb561<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb561,sheet = "56",t_empleo, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb561,"56",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb561,"56",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb561,"Tabulados_DIEE_2019.xlsx",overwrite = T)

############TABULADO 57#####################################################
#     EMPLEO REGISTRADO SEGN PARTICIPACIN EN EL TOTAL                    #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), AO 2019 POR RANGO DE EDAD       #
bd_dieeact <- bd_diee%>% filter(anio == 2019 & situacion==1 )
#seleccion de variables
bd_empleorp <- bd_dieeact %>% select(empleo_rango_edad_1,empleo_rango_edad_2,
                                    empleo_rango_edad_3,empleo_rango_edad_4, 
                                    empleo_rango_edad_5,estructura_estrat,
                                    anio,situacion)

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact1 <- bd_empleorp %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_empleore1 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_1,na.rm=T), porcentaje = 0)
t_empleore2 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_2,na.rm=T), porcentaje = 0)
t_empleore3 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_3,na.rm=T), porcentaje = 0)
t_empleore4 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_4,na.rm=T), porcentaje = 0)
t_empleore5 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangose1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_empleore1))
t_rangose2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_empleore2))
t_rangose3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_empleore3))
t_rangose4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_empleore4))
t_rangose5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_empleore5))

tablae1 <- data.frame (rbind(t_rangose1,t_rangose2,t_rangose3, t_rangose4, t_rangose5))
total <- sum(tablae1$total_empleo,na.rm = T)
tablae1$porcentaje <- tablae1$total_empleo/total
v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb57<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb57,sheet = "57" ,v_total,startCol = 1,startRow = 7,colNames = F)
writeData(wb57,sheet = "57","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb57,sheet = "57",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb57,sheet = "5",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb57,sheet = "57",tablae1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb57,"57",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb57,"57",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb57,"57",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb57,"Tabulados_DIEE_2019.xlsx",overwrite = T)

############TABULADO 58#####################################################
#      EMPLEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL                   #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019 POR FORMA INSTITUCIONAL#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_empleoins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_empleoins$total_empleo,na.rm =T )
t_empleoins$porcentaje <- t_empleoins$total_empleo / total

#Lectura catalogo de variables.
des_empleoinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empleoinst,t_empleoins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb58 <-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb58,sheet = "58","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb58,sheet = "58",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb58,sheet = "58",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb58,sheet = "58",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb58,"58",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb58,"58",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb58,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 59################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2019POR TAMANO DE EMPRESA                                 #

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_empleo,empleo,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanop_empleo) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo/ total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanop_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb59<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb59,sheet = "59","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb59,sheet = "59",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb59,sheet = "59",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb59,sheet = "59",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb59,"59",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb59,"59",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb59,"59",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb59,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##############TABULADO 60######################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#            ANIO 2019 POR SECTOR ECONOMICO                                   #     

#seleccion de variables###
bd_sector <- bd_diee %>% select(gsectores,empleo,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_sector %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo/ total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb60<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb60,sheet = "60","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb60,sheet = "60",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb60,sheet = "60",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb60,sheet = "60",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb60,"60",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb60,"60",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb60,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#################TABULADO 61##############################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019#
#                    POR ACTIVIDAD ECONOMICA                                             #

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,empleo,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_act %>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_empleo,na.rm =T )
t_secact$porcentaje <- t_secact$total_empleo / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_secact,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb61<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb61,sheet = "61","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb61,sheet = "61",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb61,sheet = "61",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb61,sheet = "61",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb61,"61",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb61,"61",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb61,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 62#########################################################
##EMPLEO SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019#
#                                POR PROVINCIA                                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,empleo,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2019 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb62 <-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb62,sheet = "62","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb62,sheet = "62",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb62,sheet = "62",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb62,sheet = "62",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb62,"62",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb62,"62",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb62,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 63#############################################
##MASA SALARIAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2019#
#                          POR ANIO                                        #

##BASE GENERAL 2011
d_remuneracion1 <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact1 <- bd_diee1 %>% filter(anio==2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2006-2011
t_remuneraciones1 <- bd_dieeact1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb63<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb63,sheet = "63",t_remuneraciones1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb63,"63",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb63,"63",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb63,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##BASE GENERAL 2012-2019
d_remuneracion <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact <- d_remuneracion %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2019
t_remuneraciones <- bd_dieeact %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb631<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb631,sheet = "63",t_remuneraciones, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb631,"63",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb631,"63",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb631,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 64: CONSTANTE#################
#           MASA SALARIAL CONSTANTE            #

#lectura de base 2011
bd_dieemsc <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc <- bd_dieemsc %>% filter (anio == 2011 & situacion == 1& estructura_estrat ==1)
t_masa2011 <- d_dieemsc %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb642<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb642,sheet = "64",t_masa2011, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado642 <- saveWorkbook(wb642,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2012
bd_dieemsc1 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc1 <- bd_dieemsc1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat ==1)
t_masa2012 <- d_dieemsc1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb643<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb643,sheet = "64",t_masa2012, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado643 <- saveWorkbook(wb643,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2013
bd_dieemsc2 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc2 <- bd_dieemsc2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat ==1)
t_masa2013 <- d_dieemsc2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb644<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb644,sheet = "64",t_masa2013, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado644 <- saveWorkbook(wb644,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2014
bd_dieemsc3 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc3 <- bd_dieemsc3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat ==1)
t_masa2014 <- d_dieemsc3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb645<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb645,sheet = "64",t_masa2014, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado645 <- saveWorkbook(wb645,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2015
bd_dieemsc4 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc4 <- bd_dieemsc4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat ==1)
t_masa2015 <- d_dieemsc4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb646<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb646,sheet = "64",t_masa2015, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado646 <- saveWorkbook(wb646,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2016
bd_dieemsc5 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc5 <- bd_dieemsc5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat ==1)
t_masa2016 <- d_dieemsc5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb647<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb647,sheet = "64",t_masa2016, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado647 <- saveWorkbook(wb647,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2017
bd_dieemsc6 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc6 <- bd_dieemsc6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat ==1)
t_masa2017 <- d_dieemsc6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb648<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb648,sheet = "64",t_masa2017, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb648,"64",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb648,"64",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado648 <- saveWorkbook(wb648,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2018
bd_dieemsc8 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc8 <- bd_dieemsc8 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat ==1)
t_masa2018 <- d_dieemsc8 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb649<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb649,sheet = "64",t_masa2018, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb649,"64",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb649,"64",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado648 <- saveWorkbook(wb649,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#lectura de base 2019
bd_dieemsc9 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc9 <- bd_dieemsc9 %>% filter (anio == 2019 & situacion == 1 & estructura_estrat ==1)
t_masa2019 <- d_dieemsc9 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.344842799337)*100,na.rm=T))
#Exportar resultados a excel
wb6410<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb6410,sheet = "64",t_masa2019, startCol = 1,startRow = 15,colNames = F) ##escribir
addStyle(wb6410,"64",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb6410,"64",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado6410 <- saveWorkbook(wb6410,"Tabulados_DIEE_2019.xlsx",overwrite = T)

####################TABULADO 65###################################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019#
#               POR FORMA INSTITUCIONAL                                                          #

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,forma_institucional,situacion, estructura_estrat)
bd_dieems <- bd_remuneraciones%>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_remuneracionesins <- bd_dieems %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb65<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb65,sheet = "65","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb65,sheet = "65",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb65,sheet = "65",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb65,sheet = "65",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb65,"65",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb65,"65",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb65,"Tabulados_DIEE_2019.xlsx",overwrite = T)

###################TABULADO 66###################################################################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019#
#             POR TAMANO DE EMPRESA                                                             #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,tamanop_plazas,situacion, estructura_estrat)
bd_dieetam <- bd_diee%>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)
      
#calculo#
t_tamanoremu <- bd_dieetam %>% group_by(tamanop_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb66<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb66,sheet = "66","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb66,sheet = "66",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb66,sheet = "66",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb66,sheet = "66",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb66,"66",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb66,"66",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb66,"66",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb66,"Tabulados_DIEE_2019.xlsx",overwrite = T)

#######################TABULADO 67################################################################
#"MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2019#
#                   POR SECTOR ECONOMICO                                                         #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,gsectores,situacion, estructura_estrat)
bd_dieese <- bd_diee%>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorremu<- bd_dieese %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total

#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb67<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb67,sheet = "67","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb67,sheet = "67",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb67,sheet = "67",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb67,sheet = "67",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb67,"67",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb67,"67",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb67,"Tabulados_DIEE_2019.xlsx",overwrite = T)

############TABULADO 68####################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2019#
#       POR ACTIVIDAD ECONOMICA                                           #  

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_seccion,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccre <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccre$total_remu,na.rm =T )
t_seccre$porcentaje <- t_seccre$total_remu / total

#Lectura catalogo de variables.
des_seccre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccre,t_seccre,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb68<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb68,sheet = "68","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb68,sheet = "68",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb68,sheet = "68",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb68,sheet = "68",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb68,"68",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb68,"68",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb68,"Tabulados_DIEE_2019.xlsx",overwrite = T)

##########TABULADO 69################################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2019 POR PROVINCIA#

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_provincia,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2019 & situacion==1 & estructura_estrat==1)

#calculo#
t_provre <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provre$total_remu,na.rm =T )
t_provre$porcentaje <- t_provre$total_remu / total
 
#Lectura catalogo de variables.
des_provre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provre,t_provre,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb69<-loadWorkbook(file = "Tabulados_DIEE_2019.xlsx")
writeData(wb69,sheet = "69","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb69,sheet = "69",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb69,sheet = "69",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb69,sheet = "69",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb69,"69",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb69,"69",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb69,"Tabulados_DIEE_2019.xlsx",overwrite = T)
